@@ -1,8 +1,8 @@
 #!/usr/bin/env python
-
+# linHDD.py version 0.3
 ##############################################################################
-# c2005 by Paul Sherman <psherma1@rochester.rr.com> http://www.pcbypaul.com  #
-#									     #
+# c2005-2007 by Paul Sherman <psherma1@rochester.rr.com>	             #
+# http://www.pcbypaul.com						     #
 # This program is free software; you can redistribute it and/or		     #
 # modify it under the terms of the GNU General Public License		     #
 # as published by the Free Software Foundation; either version 2	     #
@@ -125,7 +125,7 @@ class DriveWin:
 	def get_free(self, prt):
 		myline = ""
 		myperc = ""
-		r = commands.getoutput("df")
+		r = commands.getoutput("df -P")
 		if len(r):
 			r1 = string.split(r, "\n")
 			for l in r1:
@@ -141,7 +141,7 @@ class DriveWin:
 				return myperc
 				
 				
-	def get_prt_lst(self, drv):
+	def get_prt_lst(self, drv):	
 		self.prt_lst = []
 		prts_raw = commands.getoutput('fdisk -l %s' % drv)
 		prt_lines = prts_raw.split("\n")
@@ -159,7 +159,7 @@ class DriveWin:
 		for ide_dev in "ide0", "ide1":
 			for disk_dev in "hda", "hdb", "hdc", "hdd", "hde", "hdf", "hdg", "hdh":
 				if commands.getoutput('cat /proc/ide/%s/%s/media' % (ide_dev, disk_dev))  == "disk":
-					drives.append(disk_dev)		
+					drives.append(disk_dev)	
 		return drives
 	
 		
@@ -209,7 +209,7 @@ class DriveWin:
 
 	def reset_btns(self):
 		if os.getuid() == 0:
-			ret = commands.getoutput('df')
+			ret = commands.getoutput('df -P')
 			act = self.cb_part.get_active_text()
 			if re.search(act, ret):# partition is mounted
 				self.cb_format.set_sensitive(False)
@@ -258,13 +258,13 @@ class DriveWin:
 		
 	def mk_prt(self, btn):
 		# put in warning to nmount is any partition on drv is mounted
-		ret = commands.getoutput('df')
+		ret = commands.getoutput('df -P')
 		drv = self.combo.get_active_text()
 		first = False
 		umount_str = ""
 		if re.search(drv, ret):	
 			r_mounted = []
-			r = commands.getoutput('df')
+			r = commands.getoutput('df -P')
 			str_list = []
 			str_list.append('You should unmount any partitions on %s \nbefore you partition the drive. Among other reasons, "umount" will not allow you to unmount a drive that is busy, so you do not have to worry about destroying the system by attempting to partition your "boot" drive by accident.\n The following partition(s) are currently mounted:\n\n' % drv)
 			p_lines = r.split('\n')
@@ -379,7 +379,7 @@ class DriveWin:
 		self.prt_lst = self.get_prt_lst(init_drv)
 		self.d1 = self.get_params(init_drv)
 		self.perc = self.get_free(self.prt_lst[0])
-		if self.perc == None:
+		if self.perc == '':
 			self.perc = "0%"
 			self.frac = 0
 		else:
@@ -392,7 +392,7 @@ class DriveWin:
 
 
 		self.window = gtk.Window( type=gtk.WINDOW_TOPLEVEL)
-		self.window.set_title("linHDD - 0.2")
+		self.window.set_title("linHDD - 0.3")
 		self.window.set_default_size(530, 426)
 		self.window.set_border_width(10)
 		self.window.set_position(gtk.WIN_POS_CENTER)
